/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.asset.tags.internal.service;

import com.liferay.asset.kernel.model.AssetTag;
import com.liferay.asset.kernel.service.AssetTagLocalService;
import com.liferay.asset.kernel.service.AssetTagLocalServiceWrapper;
import com.liferay.asset.tag.stats.service.AssetTagStatsLocalService;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.service.ServiceWrapper;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Eudaldo Alonso
 */
@Component(immediate = true, service = ServiceWrapper.class)
public class AssetTagStatsAssetTagLocalServiceWrapper
	extends AssetTagLocalServiceWrapper {

	public AssetTagStatsAssetTagLocalServiceWrapper() {
		super(null);
	}

	public AssetTagStatsAssetTagLocalServiceWrapper(
		AssetTagLocalService assetTagLocalService) {

		super(assetTagLocalService);
	}

	@Override
	public AssetTag decrementAssetCount(long tagId, long classNameId)
		throws PortalException {

		AssetTag tag = super.decrementAssetCount(tagId, classNameId);

		_assetTagStatsLocalService.updateTagStats(tagId, classNameId);

		return tag;
	}

	@Override
	public void deleteTag(AssetTag tag) throws PortalException {
		super.deleteTag(tag);

		_assetTagStatsLocalService.deleteTagStatsByTagId(tag.getTagId());
	}

	@Override
	public AssetTag incrementAssetCount(long tagId, long classNameId)
		throws PortalException {

		AssetTag tag = super.incrementAssetCount(tagId, classNameId);

		_assetTagStatsLocalService.updateTagStats(tagId, classNameId);

		return tag;
	}

	@Reference
	private AssetTagStatsLocalService _assetTagStatsLocalService;

}